netapp_ontap.models.lun_map_lun API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_map_lun`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunMapLunSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunMapLun object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the lun_map_lun.

  `name GET POST`

    The fully qualified path name of the LUN composed of a "/vol" prefix, the volume name, the (optional) qtree name, and file name of the LUN. Valid in POST.

    Example: /vol/volume1/qtree1/lun1

  `node GET POST PATCH`

    The node field of the lun_map_lun.

  `uuid GET POST`

    The unique identifier of the LUN. Valid in POST.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412